document.addEventListener('DOMContentLoaded', function() {
  const canvas = document.getElementById('networkCanvas');
  const ctx = canvas.getContext('2d');
  const trainButton = document.getElementById('trainButton');
  const progress = document.getElementById('trainingProgress');
  
  let isTraining = false;

  function resizeCanvas() {
    const container = canvas.parentElement;
    canvas.width = container.offsetWidth;
    canvas.height = container.offsetHeight;
  }

  window.addEventListener('resize', resizeCanvas);
  resizeCanvas();

  function drawNetwork() {
    const innerUnits = parseInt(document.getElementById('innerUnits').value);
    const outerUnits = parseInt(document.getElementById('outerUnits').value);
    
    ctx.clearRect(0, 0, canvas.width, canvas.height);
    
    // Network visualization logic here
    const inputLayer = 5; // Fixed input dimension
    const layers = [inputLayer, innerUnits, outerUnits, 1];
    const spacing = canvas.width / (layers.length + 1);
    const maxNodes = Math.max(...layers);
    const nodeRadius = Math.min(spacing * 0.2, canvas.height / (maxNodes * 3));

    // Draw nodes and connections
    layers.forEach((nodeCount, layerIndex) => {
      const x = spacing * (layerIndex + 1);
      const layerHeight = nodeCount * (nodeRadius * 3);
      const startY = (canvas.height - layerHeight) / 2;

      for (let i = 0; i < nodeCount; i++) {
        const y = startY + i * (nodeRadius * 3) + nodeRadius * 1.5;
        
        // Draw node
        ctx.beginPath();
        ctx.arc(x, y, nodeRadius, 0, Math.PI * 2);
        ctx.fillStyle = `rgba(42, 107, 158, ${0.7 + (layerIndex / layers.length) * 0.3})`;
        ctx.fill();
        
        // Draw connections to next layer
        if (layerIndex < layers.length - 1) {
          const nextLayerNodes = layers[layerIndex + 1];
          const nextX = spacing * (layerIndex + 2);
          const nextLayerHeight = nextLayerNodes * (nodeRadius * 3);
          const nextStartY = (canvas.height - nextLayerHeight) / 2;

          for (let j = 0; j < nextLayerNodes; j++) {
            const nextY = nextStartY + j * (nodeRadius * 3) + nodeRadius * 1.5;
            ctx.beginPath();
            ctx.moveTo(x + nodeRadius, y);
            ctx.lineTo(nextX - nodeRadius, nextY);
            ctx.strokeStyle = 'rgba(74, 144, 226, 0.2)';
            ctx.stroke();
          }
        }
      }
    });
  }

  function updateMetrics(metrics) {
    document.querySelector('#aucMetric .metric-value').textContent = 
      metrics.auc.toFixed(4);
    document.querySelector('#ksMetric .metric-value').textContent = 
      metrics.ks.toFixed(4);
    document.querySelector('#loglossMetric .metric-value').textContent = 
      metrics.logLoss.toFixed(4);
  }

  function simulateTraining() {
    if (isTraining) return;
    isTraining = true;
    trainButton.disabled = true;
    
    let epoch = 0;
    const totalEpochs = parseInt(document.getElementById('epochs').value);
    
    const trainingInterval = setInterval(() => {
      epoch++;
      
      // Simulate metrics
      const progress = epoch / totalEpochs;
      const metrics = {
        auc: 0.5 + (0.4 * progress) + (Math.random() * 0.1),
        ks: 0.3 + (0.5 * progress) + (Math.random() * 0.1),
        logLoss: 0.7 - (0.5 * progress) + (Math.random() * 0.1)
      };
      
      updateMetrics(metrics);
      progress.textContent = `Training Progress: ${Math.round(progress * 100)}%`;
      
      if (epoch >= totalEpochs) {
        clearInterval(trainingInterval);
        isTraining = false;
        trainButton.disabled = false;
        progress.textContent = 'Training Complete!';
      }
    }, 100);
  }

  // Event listeners
  trainButton.addEventListener('click', simulateTraining);
  
  // Initial draw
  drawNetwork();
  
  // Update visualization when parameters change
  document.getElementById('innerUnits').addEventListener('change', drawNetwork);
  document.getElementById('outerUnits').addEventListener('change', drawNetwork);
});
